# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Name:         default.py
# Purpose:      default values and constants
#
# Author:       Marco de Freitas
#
# Copyright:    Copyright © 2021 Marco de Freitas
#
# License:      GNU Lesser General Public License 3
# -----------------------------------------------------------------------------
"""This module provides a bunch of default values for music concepts

The cycle of note names
NAMES_WHEEL=("a","b","c","d","e","f","g")


The default scale. Build by mapping note names cycle to default
scale structure in semi-tones. Blank spaces generated by whole steps
have None as name.
SCALE=("a",None,"b","c",None,"d",None,"e","f",None,"g",None)

The default degrees of the major scale mesured in semitones.
DEGREES=(0,2,4,5,7,9,11,12)

Generic names of the major scale intervals.
INTERVALS=("first","second","third","forth","fifth","sixth","seventh","eighth")

Default accidentals string with their lower/higer semi-tone value
ACCIDENTALS={'#':'1', 'b':'-1'}

"""


# Note names list
NOTE_NAMES = ["a", "b", "c", "d", "e", "f", "g"]

# Accidentals dictionary where label:value
ACCIDENTALS = {'#': 1, 'b': -1, '': 0}



# for interval calculation, we work with natural minor scale because indexing match note naming 0=a etc
DEFAULT_SCALE = ('a', None, 'b', 'c', None, 'd', None, 'e', 'f', None, 'g', None) # a natural minor scale structure
DEFAULT_SCALE_semitones = (0, 2, 3, 5, 7, 8, 10) # successive intervals in half-steps

# Major scale, true usual default scale for interval naming
MAJOR_DEGREES_semitones = (0, 2, 4, 5, 7, 9, 11, 12)
MAJOR_DEGREES_Names = ('first', 'second', 'third', 'fourth', 'fifth', 'sixth', 'seventh', 'eighth', 'nineth', 'tenth')

# intervals names, types
INTERVALS = (
    'unison', 'second', 'third', 'fourth', 'fifth', 'sixth', 'seventh', 'octave', 'ninth', 'tenth', 'eleventh',
    'twelfth',
    "thirteenth", 'fourteenth', 'fifteenth', 'sixteenth')
INTERVALS_types = (
    'Perfect', 'Major', 'Major', 'Perfect', 'Perfect', 'Major', 'Major', 'Perfect', 'Perfect', 'Major', 'Major',
    'Perfect',
    'Perfect', 'Major', 'Major', 'Perfect')



ADJECTIVS_perf = ('double diminished','diminished', 'Perfect', 'augmented','double augmented')
ADJECTIVS_majmin = ('double diminished','diminished', 'minor', 'Major', 'augmented','double augmented')
