import unittest

from musenot.intervals import *

class testAbsIntervalsMethods(unittest.TestCase):

    def setUp(self):
        self.unison           = AbsInterval('1')
        self.second_minor     = AbsInterval('b2')
        self.second_major     = AbsInterval('2')
        self.second_augmented = AbsInterval('#2')
        self.third_minor      = AbsInterval('b3')
        self.third_major      = AbsInterval('3')
        self.fourth           = AbsInterval('4')
        self.fourth_augmented = AbsInterval('#4')
        self.fifth_diminished = AbsInterval('b5')
        self.fifth            = AbsInterval('5')
        self.fifth_augmented  = AbsInterval('#5')
        self.sixth_diminished = AbsInterval('b6')
        self.sixth            = AbsInterval('6')
        self.sixth_augmented  = AbsInterval('#6')
        self.seventh_double_diminished = AbsInterval('bb7')
        self.seventh_minor    = AbsInterval('b7')
        self.seventh          = AbsInterval('7')
        self.octave           = AbsInterval('8')

        self.notes_for_absintervals = {}
        for note in ['a', 'b', 'c', 'd', 'e', 'f', 'g',
                     'a#', 'b#', 'c#', 'd#', 'e#', 'f#', 'g#',
                      'bb', 'cb', 'db', 'eb', 'fb', 'gb', 'ab']:
            self.notes_for_absintervals[note] = AbsNote(note)

        self.results_for_second_major = {}
        for note in ['b', 'c#', 'd', 'e', 'f#', 'g', 'a',
                     'b#', 'c##', 'd#', 'e#', 'f##', 'g#', 'a#',
                      'c', 'db', 'eb', 'f', 'gb', 'ab', 'bb']:
            self.results_for_second_major[note] = AbsNote(note)




    def testAbsIntervalsAttributs(self):
        self.assertEqual(self.unison.half_steps,           0)
        self.assertEqual(self.second_minor.half_steps,     1)
        self.assertEqual(self.second_major.half_steps,     2)
        self.assertEqual(self.second_augmented.half_steps, 3)
        self.assertEqual(self.third_minor.half_steps,      3)
        self.assertEqual(self.third_major.half_steps,      4)
        self.assertEqual(self.fourth.half_steps,           5)
        self.assertEqual(self.fourth_augmented.half_steps, 6)
        self.assertEqual(self.fifth_diminished.half_steps, 6)
        self.assertEqual(self.fifth.half_steps,            7)
        self.assertEqual(self.fifth_augmented.half_steps,  8)
        self.assertEqual(self.sixth_diminished.half_steps, 8)
        self.assertEqual(self.sixth.half_steps,            9)
        self.assertEqual(self.sixth_augmented.half_steps,  10)
        self.assertEqual(self.seventh_double_diminished.half_steps,  9)
        self.assertEqual(self.seventh_minor.half_steps,  10)






    def testAbsIntervalMethods(self):

        # __add__ AbsNote


        for notes, results in zip(self.notes_for_absintervals, self.results_for_second_major):
            self.assertEqual(self.notes_for_absintervals[notes] + self.second_major,self.results_for_second_major[results] )



        # __ad__ AbsInterval
        self.uni_unison       = self.unison + self.unison
        self.uni_second_minor = self.unison + self.second_minor


        self.assertEqual(self.unison.name == self.unison.name, True)

        # __eq__ test only half-steps
        self.assertEqual(self.unison + self.second_minor     , self.second_minor)
        self.assertEqual(self.unison + self.second_major     , self.second_major)
        self.assertEqual(self.unison + self.second_augmented , self.second_augmented)
        self.assertEqual(self.unison + self.third_minor      , self.third_minor)
        self.assertEqual(self.unison + self.third_major      , self.third_major)
        self.assertEqual(self.unison + self.fourth           , self.fourth)
        self.assertEqual(self.unison + self.fourth_augmented , self.fourth_augmented)
        self.assertEqual(self.unison + self.fifth            , self.fifth)

        self.assertEqual(self.second_minor + self.unison          , self.second_minor)
        self.assertEqual(self.second_minor + self.second_major    , self.third_minor)
        self.assertEqual(self.second_minor + self.second_augmented, self.third_major)
        self.assertEqual(self.second_minor + self.third_major     , self.fourth)
        self.assertEqual(self.second_minor + self.fourth          , self.fifth_diminished)
        self.assertEqual(self.second_minor + self.fourth_augmented, self.fifth)

        # __add__ AbsNote

if __name__ == '__main__':
    unittest.main()
