import unittest

from musenot.notename import NoteName

class testNotesNamesMethods(unittest.TestCase):

    def setUp(self):

        # { 'a' : NoteName('a'), etc.....
        self.note_names_from_string={}
        for key in ['a','b', 'c', 'd', 'e', 'f', 'g']:
            self.note_names_from_string[key]=NoteName(key)

        # { 'a' : NoteName(0), etc.....
        self.note_names_from_index={}
        for index, key in zip ([0,1,2,3,4,5,6], ['a','b', 'c', 'd', 'e', 'f', 'g']) :
            self.note_names_from_index[key] = NoteName(index)



    def testNoteNamesAttributs(self):

        # Attributs of instances initialized from string

        # NoteName('a') label == 'a' etc.
        for keys, label in zip(self.note_names_from_string.keys(), ['a','b', 'c', 'd', 'e', 'f', 'g']) :
            self.assertEqual(self.note_names_from_string[keys].label,label)

        # NoteName('a').index == 0 etc.
        for keys, index in zip(self.note_names_from_string.keys(), [0, 1, 2, 3, 4, 5, 6, 7]) :
            self.assertEqual(self.note_names_from_string[keys].index,index)

        # NoteName('a').index_in_ref_scale == 0 etc.
        for keys, index_in_ref_scale in zip(self.note_names_from_string.keys(), [0, 2, 3, 5, 7, 8, 10]) :
            self.assertEqual(self.note_names_from_string[keys].index_in_ref_scale,index_in_ref_scale)

        # Attributs of instances initialized from index

        # NoteName(0) label == 'a' etc.
        for keys, label in zip(self.note_names_from_string.keys(), ['a','b', 'c', 'd', 'e', 'f', 'g']) :
            self.assertEqual(self.note_names_from_string[keys].label,label)

        # NoteName(0).index == 0 etc.
        for keys, index in zip(self.note_names_from_index.keys(), [0, 1, 2, 3, 4, 5, 6, 7]) :
            self.assertEqual(self.note_names_from_index[keys].index,index)

        # NoteName(0).index_in_ref_scale == 0 etc.
        for keys, index_in_ref_scale in zip(self.note_names_from_index.keys(), [0, 2, 3, 5, 7, 8, 10]) :
            self.assertEqual(self.note_names_from_index[keys].index_in_ref_scale,index_in_ref_scale)




    def testNoteNamesMethods(self):


        # NoteName('a') - NoteName('a') == 0
        # NoteName('a') - NoteName('b') == 1
        # NoteName('a') - NoteName('c') == 2 etc.
        for key, value in zip(['a', 'b', 'c', 'd', 'e', 'f', 'g'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['a'].diff(self.note_names_from_string[key]), value)

        # NoteName('b') -  etc.
        for key, value in zip(['b', 'c', 'd', 'e', 'f', 'g', 'a'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['b'].diff(self.note_names_from_string[key]), value)

        # NoteName('c') -   etc.
        for key, value in zip(['c', 'd', 'e', 'f', 'g', 'a', 'b'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['c'].diff(self.note_names_from_string[key]), value)

        # NoteName('d') -  etc.
        for key, value in zip([ 'd', 'e', 'f', 'g', 'a', 'b', 'c'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['d'].diff(self.note_names_from_string[key]), value)

        # NoteName('e') -  etc.
        for key, value in zip(['e', 'f', 'g', 'a', 'b', 'c',  'd'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['e'].diff(self.note_names_from_string[key]), value)

        # NoteName('f') -  etc.
        for key, value in zip([ 'f', 'g', 'a', 'b', 'c',  'd', 'e'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['f'].diff(self.note_names_from_string[key]), value)

        # NoteName('g') -  etc.
        for key, value in zip([ 'g', 'a', 'b', 'c',  'd', 'e', 'f'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_string['g'].diff(self.note_names_from_string[key]), value)

        # The same, but from index

        for key, value in zip(['a', 'b', 'c', 'd', 'e', 'f', 'g'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['a'].diff(self.note_names_from_index[key]), value)

        # NoteName('b') -  etc.
        for key, value in zip(['b', 'c', 'd', 'e', 'f', 'g', 'a'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['b'].diff(self.note_names_from_index[key]), value)

        # NoteName('c') -   etc.
        for key, value in zip(['c', 'd', 'e', 'f', 'g', 'a', 'b'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['c'].diff(self.note_names_from_index[key]), value)

        # NoteName('d') -  etc.
        for key, value in zip([ 'd', 'e', 'f', 'g', 'a', 'b', 'c'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['d'].diff(self.note_names_from_index[key]), value)

        # NoteName('e') -  etc.
        for key, value in zip(['e', 'f', 'g', 'a', 'b', 'c',  'd'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['e'].diff(self.note_names_from_index[key]), value)

        # NoteName('f') -  etc.
        for key, value in zip([ 'f', 'g', 'a', 'b', 'c',  'd', 'e'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['f'].diff(self.note_names_from_index[key]), value)

        # NoteName('g') -  etc.
        for key, value in zip([ 'g', 'a', 'b', 'c',  'd', 'e', 'f'], [0, 1, 2, 3, 4, 5, 6]):
            self.assertEqual(self.note_names_from_index['g'].diff(self.note_names_from_index[key]), value)
